==> lyx-1.6.9.tar.gz: lyx-1.6.9/src/frontends/qt4/liblyxqt4.cpp <==

#include "ButtonPolicy.cpp" 
#include "ButtonPolicy.h" 
#include "Dialog.cpp" 
#include "Dialog.h" 
#include "Resources.cpp" 
#include "Action.cpp" 
#include "BulletsModule.cpp" 
#include "ButtonController.cpp" 
#include "ColorCache.cpp" 
#include "CustomizedWidgets.cpp" 
#include "EmptyTable.cpp" 
#include "FileDialog.cpp" 
#include "FloatPlacement.cpp" 
#include "GuiAbout.cpp" 
#include "GuiAlert.cpp" 
#include "GuiApplication.cpp" 
#include "GuiBibitem.cpp" 
#include "GuiBibtex.cpp" 
#include "GuiBox.cpp" 
#include "GuiBranch.cpp" 
#include "GuiBranches.cpp" 
#include "GuiChanges.cpp" 
#include "GuiCharacter.cpp" 
#include "GuiCitation.cpp" 
#include "GuiClipboard.cpp" 
#include "GuiCommandBuffer.cpp" 
#include "GuiCommandEdit.cpp" 
#include "GuiCompleter.cpp" 
#include "GuiDelimiter.cpp" 
#include "GuiDialog.cpp" 
#include "GuiDocument.cpp" 
#include "GuiErrorList.cpp" 
#include "GuiERT.cpp" 
#include "GuiExternal.cpp" 
#include "GuiFloat.cpp" 
#include "GuiFontExample.cpp" 
#include "GuiFontLoader.cpp" 
#include "GuiFontMetrics.cpp" 
#include "GuiGraphics.cpp" 
#include "GuiHSpace.cpp" 
#include "GuiHyperlink.cpp" 
#include "GuiIdListModel.cpp" 
#include "GuiImage.cpp" 
#include "GuiInclude.cpp" 
#include "GuiInfo.cpp" 
#include "GuiKeySymbol.cpp" 
#include "GuiLabel.cpp" 
#include "GuiListings.cpp" 
#include "GuiLog.cpp" 
#include "GuiMathMatrix.cpp" 
#include "GuiNomencl.cpp" 
#include "GuiNote.cpp" 
#include "GuiPainter.cpp" 
#include "GuiParagraph.cpp" 
#include "GuiPrefs.cpp" 
#include "GuiPrint.cpp" 
#include "GuiRef.cpp" 
#include "GuiSearch.cpp" 
#include "GuiSelection.cpp" 
#include "GuiSelectionManager.cpp" 
#include "GuiSendto.cpp" 
#include "GuiSetBorder.cpp" 
#include "GuiShowFile.cpp" 
#include "GuiSpellchecker.cpp" 
#include "GuiSymbols.cpp" 
#include "GuiTabular.cpp" 
#include "GuiTabularCreate.cpp" 
#include "GuiTexinfo.cpp" 
#include "GuiThesaurus.cpp" 
#include "GuiToc.cpp" 
#include "GuiToolbar.cpp" 
#include "GuiView.cpp" 
#include "GuiViewSource.cpp" 
#include "GuiVSpace.cpp" 
#include "GuiWorkArea.cpp" 
#include "GuiWrap.cpp" 
#include "IconPalette.cpp" 
#include "InsertTableWidget.cpp" 
#include "LengthCombo.cpp" 
#include "LyXFileDialog.cpp" 
#include "LaTeXHighlighter.cpp" 
#include "Menus.cpp" 
#include "PanelStack.cpp" 
#include "qt_helpers.cpp" 
#include "TocModel.cpp" 
#include "TocWidget.cpp" 
#include "Toolbars.cpp" 
#include "Validator.cpp"

==> lyx-2.1.0.tar.gz: lyx-2.1.0/src/frontends/qt4/liblyxqt4.cpp <==

#include "ButtonPolicy.cpp" 
#include "ButtonPolicy.h" 
#include "Dialog.cpp" 
#include "Dialog.h" 
#include "Resources.cpp" 
#include "Action.cpp" 
#include "BulletsModule.cpp" 
#include "ButtonController.cpp" 
#include "CategorizedCombo.cpp" 
#include "ColorCache.cpp" 
#include "CustomizedWidgets.cpp" 
#include "EmptyTable.cpp" 
#include "FancyLineEdit.cpp" 
#include "FileDialog.cpp" 
#include "FindAndReplace.cpp" 
#include "FloatPlacement.cpp" 
#include "GuiAbout.cpp" 
#include "GuiAlert.cpp" 
#include "GuiApplication.cpp" 
#include "GuiBibitem.cpp" 
#include "GuiBibtex.cpp" 
#include "GuiBox.cpp" 
#include "GuiBranch.cpp" 
#include "GuiBranches.cpp" 
#include "GuiChanges.cpp" 
#include "GuiCharacter.cpp" 
#include "GuiCitation.cpp" 
#include "GuiClipboard.cpp" 
#include "GuiCommandBuffer.cpp" 
#include "GuiCommandEdit.cpp" 
#include "GuiCompare.cpp" 
#include "GuiCompareHistory.cpp" 
#include "GuiCompleter.cpp" 
#include "GuiDelimiter.cpp" 
#include "GuiDialog.cpp" 
#include "GuiDocument.cpp" 
#include "GuiErrorList.cpp" 
#include "GuiERT.cpp" 
#include "GuiExternal.cpp" 
#include "GuiFontExample.cpp" 
#include "GuiFontLoader.cpp" 
#include "GuiFontMetrics.cpp" 
#include "GuiGraphics.cpp" 
#include "GuiHSpace.cpp" 
#include "GuiHyperlink.cpp" 
#include "GuiIdListModel.cpp" 
#include "GuiImage.cpp" 
#include "GuiInclude.cpp" 
#include "GuiIndex.cpp" 
#include "GuiIndices.cpp" 
#include "GuiInfo.cpp" 
#include "GuiKeySymbol.cpp" 
#include "GuiLabel.cpp" 
#include "GuiLine.cpp" 
#include "GuiListings.cpp" 
#include "GuiLog.cpp" 
#include "GuiMathMatrix.cpp" 
#include "GuiNomenclature.cpp" 
#include "GuiNote.cpp" 
#include "GuiPainter.cpp" 
#include "GuiParagraph.cpp" 
#include "GuiPhantom.cpp" 
#include "GuiPrefs.cpp" 
#include "GuiPrint.cpp" 
#include "GuiPrintindex.cpp" 
#include "GuiPrintNomencl.cpp" 
#include "GuiProgress.cpp" 
#include "GuiProgressView.cpp" 
#include "GuiRef.cpp" 
#include "GuiSearch.cpp" 
#include "GuiSelection.cpp" 
#include "GuiSelectionManager.cpp" 
#include "GuiSendto.cpp" 
#include "GuiSetBorder.cpp" 
#include "GuiShowFile.cpp" 
#include "GuiSpellchecker.cpp" 
#include "GuiSymbols.cpp" 
#include "GuiTabular.cpp" 
#include "GuiTabularCreate.cpp" 
#include "GuiTexinfo.cpp" 
#include "GuiThesaurus.cpp" 
#include "GuiToc.cpp" 
#include "GuiToolbar.cpp" 
#include "GuiView.cpp" 
#include "GuiViewSource.cpp" 
#include "GuiVSpace.cpp" 
#include "GuiWorkArea.cpp" 
#include "GuiWrap.cpp" 
#include "IconPalette.cpp" 
#include "InGuiThread.cpp" 
#include "InsertTableWidget.cpp" 
#include "InsetParamsDialog.cpp" 
#include "InsetParamsWidget.cpp" 
#include "LengthCombo.cpp" 
#include "LyXFileDialog.cpp" 
#include "LaTeXHighlighter.cpp" 
#include "LayoutBox.cpp" 
#include "Menus.cpp" 
#include "PanelStack.cpp" 
#include "qt_helpers.cpp" 
#include "TocModel.cpp" 
#include "TocWidget.cpp" 
#include "Toolbars.cpp" 
#include "Validator.cpp"
